@@ -17,7 +17,7 @@ from pynot import extract_gui
 from pynot.functions import get_options, get_version_number
 from pynot.wavecal import rectify
 from pynot.identify_gui import create_pixtable
-from pynot.scired import raw_correction, auto_fit_background, correct_cosmics
+from pynot.scired import raw_correction, auto_fit_background, correct_cosmics, correct_raw_file
 from pynot.response import calculate_response, flux_calibrate
 
 from PyQt5.QtWidgets import QApplication
@@ -267,31 +267,31 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
         log.add_linebreak()
 
 
-    # Identify interactively for grisms that are not defined
-    # add the new pixel tables to the calib cache for future use
-    for grism_name in grisms_to_identify:
-        log.write("Starting interactive definition of pixel table for %s" % grism_name)
-        try:
-            arc_fname = arc_images_for_grism[grism_name][0]
-            if grism_name+'_pixtab' in options:
-                pixtab_fname = options[grism_name+'_pixtab']
-            else:
-                pixtab_fname = os.path.join(calib_dir, '%s_pixeltable.dat' % grism_name)
-            linelist_fname = ''
-            log.write("Input arc line frame: %s" % arc_fname)
-            poly_order, saved_pixtab_fname, msg = create_pixtable(arc_fname, grism_name,
-                                                                  pixtab_fname, linelist_fname,
-                                                                  order_wl=options['identify']['order_wl'],
-                                                                  app=app)
-            status[saved_pixtab_fname] = poly_order
-            status[grism_name+'_pixtab'] = saved_pixtab_fname
-            log.commit(msg)
-        except:
-            log.error("Identification of arc lines failed!")
-            log.fatal_error()
-            log.save()
-            print("Unexpected error:", sys.exc_info()[0])
-            raise
+    # # Identify interactively for grisms that are not defined
+    # # add the new pixel tables to the calib cache for future use
+    # for grism_name in grisms_to_identify:
+    #     log.write("Starting interactive definition of pixel table for %s" % grism_name)
+    #     try:
+    #         arc_fname = arc_images_for_grism[grism_name][0]
+    #         if grism_name+'_pixtab' in options:
+    #             pixtab_fname = options[grism_name+'_pixtab']
+    #         else:
+    #             pixtab_fname = os.path.join(calib_dir, '%s_pixeltable.dat' % grism_name)
+    #         linelist_fname = ''
+    #         log.write("Input arc line frame: %s" % arc_fname)
+    #         poly_order, saved_pixtab_fname, msg = create_pixtable(arc_fname, grism_name,
+    #                                                               pixtab_fname, linelist_fname,
+    #                                                               order_wl=options['identify']['order_wl'],
+    #                                                               app=app)
+    #         status[saved_pixtab_fname] = poly_order
+    #         status[grism_name+'_pixtab'] = saved_pixtab_fname
+    #         log.commit(msg)
+    #     except:
+    #         log.error("Identification of arc lines failed!")
+    #         log.fatal_error()
+    #         log.save()
+    #         print("Unexpected error:", sys.exc_info()[0])
+    #         raise
 
 
     # Save overview log:
@@ -361,7 +361,9 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
             log.write("Running task: Bias Combination")
             try:
                 _, bias_msg = combine_bias_frames(bias_frames, output=master_bias_fname,
-                                                  kappa=options['bias']['kappa'], overwrite=True)
+                                                  kappa=options['bias']['kappa'],
+                                                  method=options['bias']['method'],
+                                                  overwrite=True)
                 log.commit(bias_msg)
                 log.add_linebreak()
                 status['master_bias'] = master_bias_fname
@@ -390,7 +392,8 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
             try:
                 log.write("Running task: Spectral Flat Combination")
                 _, flat_msg = combine_flat_frames(flat_frames, comb_flat_fname, mbias=master_bias_fname,
-                                                  kappa=options['flat']['kappa'], overwrite=True,
+                                                  kappa=options['flat']['kappa'],
+                                                  method=options['flat']['method'], overwrite=True,
                                                   mode='spec', dispaxis=sci_img.dispaxis)
                 log.commit(flat_msg)
                 log.add_linebreak()
@@ -422,7 +425,21 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
 
 
         # Identify lines in arc frame:
-        arc_fname, = sci_img.match_files(arc_images, grism=True, slit=True, filter=True, get_closest_time=True)
+        arc_fname, = sci_img.match_files(arc_images, date=False, grism=True, slit=True, filter=True, get_closest_time=True)
+        corrected_arc2d_fname = os.path.join(output_dir, 'corr_arc2d.fits')
+        log.write("Running task: Bias and Flat Field Correction of Arc Frame")
+        try:
+            output_msg = correct_raw_file(arc_fname, bias_fname=master_bias_fname,
+                                          output=corrected_arc2d_fname, overwrite=True, overscan=50)
+            log.commit(output_msg)
+            log.add_linebreak()
+        except:
+            log.error("Bias and flat field correction of Arc frame failed!")
+            log.fatal_error()
+            print("Unexpected error:", sys.exc_info()[0])
+            raise
+
+
         if identify_interactive and identify_all:
             log.write("Running task: Arc Line Identification")
             try:
@@ -431,7 +448,7 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
                 else:
                     pixtab_fname = os.path.join(calib_dir, '%s_pixeltable.dat' % grism)
                 linelist_fname = ''
-                order_wl, pixtable, msg = create_pixtable(arc_fname, grism,
+                order_wl, pixtable, msg = create_pixtable(corrected_arc2d_fname, grism,
                                                           pixtab_fname, linelist_fname,
                                                           order_wl=options['identify']['order_wl'],
                                                           app=app)
@@ -474,7 +491,7 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
                 log.write("Running task: Calculation of Response Function")
                 log.write("Spectroscopic Flux Standard: %s" % std_fname)
                 try:
-                    response_fname, response_msg = calculate_response(std_fname, arc_fname=arc_fname,
+                    response_fname, response_msg = calculate_response(std_fname, arc_fname=corrected_arc2d_fname,
                                                                       pixtable_fname=pixtable,
                                                                       bias_fname=master_bias_fname,
                                                                       flat_fname=norm_flat_fname,
@@ -513,7 +530,7 @@ def run_pipeline(options_fname, object_id=None, verbose=False, interactive=False
         # Call rectify
         log.write("Running task: 2D Rectification and Wavelength Calibration")
         try:
-            rect_msg = rectify(corrected_2d_fname, arc_fname, pixtable, output=rect2d_fname, fig_dir=output_dir,
+            rect_msg = rectify(corrected_2d_fname, corrected_arc2d_fname, pixtable, output=rect2d_fname, fig_dir=output_dir,
                                dispaxis=sci_img.dispaxis, order_wl=order_wl, **options['rectify'])
             log.commit(rect_msg)
             log.add_linebreak()
